@@ -19,9 +19,9 @@ memoize '_get_youtubei_content', SCALAR_CACHE => [HASH => \%youtubei_cache];
 #memoize('_get_video_info');
 memoize('_ytdl_is_available');
 
-memoize('_info_from_ytdl');
-memoize('_extract_from_ytdl');
-memoize('_extract_from_invidious');
+#memoize('_info_from_ytdl');
+#memoize('_extract_from_ytdl');
+#memoize('_extract_from_invidious');
 
 use parent qw(
   WWW::PipeViewer::InitialData
@@ -43,7 +43,7 @@ WWW::PipeViewer - A simple interface to YouTube.
 
 =cut
 
-our $VERSION = '0.5.3';
+our $VERSION = '0.5.4';
 
 =head1 SYNOPSIS
 
@@ -475,7 +475,7 @@ sub lwp_get {
 
     # Too many errors. Pick another invidious instance.
     if ($url !~ m{(?:\byoutube\.com/|\bi\.ytimg\.com/)}) {
-        $self->pick_and_set_random_instance();
+        ## $self->pick_and_set_random_instance();   # see #209
     }
 
     _warn_reponse_error($response, $url);
@@ -685,7 +685,7 @@ sub pick_random_instance {
     my @candidates       = $self->select_good_invidious_instances();
     my @extra_candidates = $self->select_good_invidious_instances(lax => 1);
 
-    if (1 or $self->get_prefer_invidious) {
+    if ($self->get_prefer_invidious) {
         if (defined(my $instance = $self->_find_working_instance(\@candidates, \@extra_candidates))) {
             return $instance;
         }
@@ -937,7 +937,7 @@ sub _fallback_extract_urls {
         say STDERR ":: Using invidious to extract the streaming URLs...";
     }
 
-    push @formats, $self->_extract_from_invidious($videoID);
+    # push @formats, $self->_extract_from_invidious($videoID);
 
     if ($self->get_debug) {
         my $count = scalar(@formats);
